@@ -11,6 +11,7 @@ from typing import Any, Dict, Optional
 import urllib.request
 from uuid import uuid4
 import toml
+from rich import get_console
 
 from .version import __version__
 
@@ -41,7 +42,7 @@ def bool_ask_for_email() -> bool:
     """
     Checks the .datadiff.toml profile file for the asked_for_email key
 
-    Returns False immediately if --no-tracking
+    Returns False immediately if --no-tracking or not in an interactive terminal
 
     If found, return False (already asked for email)
 
@@ -50,7 +51,8 @@ def bool_ask_for_email() -> bool:
     Returns:
         bool: decision on whether to prompt the user for their email
     """
-    if g_tracking_enabled:
+    console = get_console()
+    if g_tracking_enabled and console.is_interactive:
         profile = _load_profile()
 
         if "asked_for_email" not in profile:
@@ -61,6 +63,17 @@ def bool_ask_for_email() -> bool:
     return False
 
 
+def bool_notify_about_extension() -> bool:
+    profile = _load_profile()
+    console = get_console()
+    if "notified_about_extension" not in profile and console.is_interactive:
+        profile["notified_about_extension"] = ""
+        with open(DEFAULT_PROFILE, "w") as conf:
+            toml.dump(profile, conf)
+        return True
+    return False
+
+
 g_tracking_enabled = True
 g_anonymous_id = None
 
